@@ -12,7 +12,7 @@ use Mojo::Template;
 
 use IO::File;
 
-our $VERSION = '0.99_06';
+our $VERSION = '0.99_07';
 
 our %feature_syntaxes = (
     literal_text              => <<END_OF_TEMPLATE,
@@ -110,9 +110,9 @@ sub benchmark_functions_for_uncached_string
         } );
 }
 
-sub benchmark_functions_for_disk_cache
+sub benchmark_functions_for_uncached_disk
 {
-    my ( $self, $template_dir, $cache_dir ) = @_;
+    my ( $self, $template_dir ) = @_;
 
     return( {
         MoTe =>
@@ -126,6 +126,13 @@ sub benchmark_functions_for_disk_cache
         } );
 }
 
+sub benchmark_functions_for_disk_cache
+{
+    my ( $self, $template_dir, $cache_dir ) = @_;
+
+    return( undef );
+}
+
 sub benchmark_functions_for_shared_memory_cache
 {
     my ( $self, $template_dir, $cache_dir ) = @_;
