@@ -12,7 +12,7 @@ use Cache::CacheFactory;
 use Cache::FastMmap;
 use CHI;
 
-our $VERSION = '0.99_06';
+our $VERSION = '0.99_07';
 
 our %feature_syntaxes = (
     literal_text              => <<END_OF_TEMPLATE,
@@ -112,6 +112,25 @@ sub benchmark_functions_for_uncached_string
         } );
 }
 
+sub benchmark_functions_for_uncached_disk
+{
+    my ( $self, $template_dir ) = @_;
+
+    return( {
+        TS =>
+            sub
+            {
+                my $t = Template::Sandbox->new(
+                    template_root => $template_dir,
+                    template      => $_[ 0 ],
+                    );
+                $t->add_vars( $_[ 1 ] );
+                $t->add_vars( $_[ 2 ] );
+                ${$t->run()};
+            },
+        } );
+}
+
 sub benchmark_functions_for_disk_cache
 {
     my ( $self, $template_dir, $cache_dir ) = @_;
