@@ -9,7 +9,7 @@ use Text::Template;
 
 use File::Spec;
 
-our $VERSION = '0.99_06';
+our $VERSION = '0.99_07';
 
 our %feature_syntaxes = (
     literal_text              => <<END_OF_TEMPLATE,
@@ -95,6 +95,23 @@ sub benchmark_functions_for_uncached_string
         } );
 }
 
+sub benchmark_functions_for_uncached_disk
+{
+    my ( $self, $template_dir ) = @_;
+
+    return( {
+        TeTe =>
+            sub
+            {
+                my $t = Text::Template->new(
+                    TYPE   => 'FILE',
+                    SOURCE => File::Spec->catfile( $template_dir, $_[ 0 ] ),
+                    );
+                $t->fill_in( HASH => [ $_[ 1 ], $_[ 2 ] ] );
+            },
+        } );
+}
+
 sub benchmark_functions_for_disk_cache
 {
     my ( $self, $template_dir, $cache_dir ) = @_;
